# sportsref
Scraping sports data from sports-reference.com and related sites

NOTE: Very much still a WIP. Feel free to use, just bear in mind that the API
is subject to change. Documentation is on the to-do list, once the API is a bit
more rigid.
